pyrestsdk.credential package — PyRESTSDK documentation

# pyrestsdk.credential package

## Module contents

Credentials

class pyrestsdk.credential.AbstractBasicCredential

  Bases: `AbstractCredential`

  Abstract Basic Credential Type

  abstract get_basic() → str

    Gets the basic credential encoded string

class pyrestsdk.credential.AbstractCredential

  Bases: `ABC`

  Abstract Credential Type

class pyrestsdk.credential.AbstractKerbroseCredential

  Bases: `AbstractCredential`

  Abstract Kerbrose Credential Type

  abstract get_principle() → str

    Gets the principle information for authing

class pyrestsdk.credential.AbstractTokenCredential

  Bases: `AbstractCredential`

  Abstract Token Credential Type

  abstract get_token() → A

    Gets the access token